@@ -20,10 +20,10 @@
 #include "karchive_p.h"
 #include "loggingcategory.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QBuffer>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QDir>
+#include <QBuffer>
+#include <QFile>
 #include <qplatformdefs.h>
 
 #include "kcompressiondevice.h"
@@ -177,7 +177,7 @@ public:
      * @return the content of this file.
      * Call data() with care (only once per file), this data isn't cached.
      */
-    QByteArray data() const Q_DECL_OVERRIDE;
+    QByteArray data() const override;
 
     /**
      * This method returns QIODevice (internal class: KLimitedIODevice)
@@ -189,7 +189,7 @@ public:
      * The returned device auto-opens (in readonly mode), no need to open it.
      * @return the QIODevice of the file
      */
-    QIODevice *createDevice() const Q_DECL_OVERRIDE;
+    QIODevice *createDevice() const override;
 
 private:
     const QByteArray m_data;
@@ -871,9 +871,8 @@ bool K7Zip::K7ZipPrivate::readPackInfo()
         packSizes.append(readNumber());
     }
 
-    int type;
     for (;;) {
-        type = readByte();
+        int type = readByte();
         if (type == kEnd) {
             break;
         }
@@ -1730,9 +1729,7 @@ void K7Zip::K7ZipPrivate::createItemsFromEntities(const KArchiveDirectory *dir,
                 unpackSizes.append(symLink.size());
             }
             fileInfos.append(fileInfo);
-        }
-
-        if (entry->isDirectory()) {
+        } else if (entry->isDirectory()) {
             fileInfo->attributes = FILE_ATTRIBUTE_DIRECTORY;
             fileInfo->attributes |= FILE_ATTRIBUTE_UNIX_EXTENSION + ((entry->permissions() & 0xFFFF) << 16);
             fileInfo->isDir = true;
